pub struct Data {
pub type: DataAssetType,
pub len: Option<i32>,
pub ext: Option<Map<String, Value>>,
}Expand description
4.6 Data Request Object
The Data Object is to be used for all non-core elements of the native unit such as Brand Name, Ratings, Review Count, Stars, Download count, descriptions etc. It is also generic for future native elements not contemplated at the time of the writing of this document. In some cases, additional recommendations are also included in the Data Asset Types table.
Fields
type: DataAssetTyperequired; integer; - Type ID of the element supported by the publisher. The publisher can display this information in an appropriate format. See Data Asset Types table for commonly used examples.
len: Option<i32>optional; integer; - Maximum length of the text in the element’s response.
ext: Option<Map<String, Value>>optional; object; - This object is a placeholder that may contain custom JSON agreed to by the parties to support flexibility beyond the standard defined in this specification.